@@ -430,7 +430,7 @@ travel_times = function(filtered_stop_times,
                            with = FALSE]
   
   if(!return_DT) {
-    rptr_names <- tibble::as_tibble(rptr_names)
+    rptr_names <- dplyr::as_tibble(rptr_names)
   }
   
   return(rptr_names)
@@ -439,11 +439,11 @@ travel_times = function(filtered_stop_times,
 #' Filter a `stop_times` table for a given date and timespan. 
 #' 
 #' @param gtfs_obj a gtfs feed
-#' @param extract_date date to extract trips from in YYYY-MM-DD format
-#' @param min_departure_time The earliest departure time. Can be given as "HH:MM:SS", 
+#' @param extract_date date to extract trips from this day (Date or "YYYY-MM-DD" string)
+#' @param min_departure_time (optional) The earliest departure time. Can be given as "HH:MM:SS", 
 #'                           hms object or numeric value in seconds.
-#' @param max_arrival_time The latest arrival time. Can be given as "HH:MM:SS", 
-#'                         hms object or numeric value in seconds
+#' @param max_arrival_time (optional) The latest arrival time. Can be given as "HH:MM:SS", 
+#'                         hms object or numeric value in seconds.
 #' 
 #' @return Filtered `stop_times` data.table for [travel_times()] and [raptor()].
 #' 
@@ -460,12 +460,16 @@ filter_stop_times = function(gtfs_obj,
                              max_arrival_time) {
   departure_time_num <- arrival_time_num <- NULL
   if(is.character(extract_date)) {
-    extract_date <- readr::parse_date(extract_date)
+    extract_date <- as.Date(extract_date)
   }
-  if(is.character(min_departure_time)) {
+  if(missing(min_departure_time)) {
+    min_departure_time <- 0 
+  } else if(is.character(min_departure_time)) {
     min_departure_time <- hhmmss_to_seconds(min_departure_time)
   }
-  if(is.character(max_arrival_time)) {
+  if(missing(max_arrival_time)) {
+    max_arrival_time <- max(gtfs_obj$stop_times$arrival_time)+1
+  } else if(is.character(max_arrival_time)) {
     max_arrival_time <- hhmmss_to_seconds(max_arrival_time)
   }
   min_departure_time <- as.numeric(min_departure_time)
@@ -556,9 +560,9 @@ set_num_times = function(stop_times_dt) {
   arrival_time <- arrival_time_num <- departure_time <- departure_time_num <- NULL
   stopifnot(is.data.table(stop_times_dt))
   if(all(c("arrival_time_num", "departure_time_num") %in% colnames(stop_times_dt))) {
-    invisible(stop_times_dt)
+    return(invisible(stop_times_dt))
   }
   stop_times_dt[,arrival_time_num := as.numeric(arrival_time)]
   stop_times_dt[,departure_time_num := as.numeric(departure_time)]
   invisible(stop_times_dt)
-}
\ No newline at end of file
+}
